Documentation
¶
Index ¶
- func NewCVOConfigInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredCVOConfigInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type CVOConfigInformer
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCVOConfigInformer ¶
func NewCVOConfigInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewCVOConfigInformer constructs a new informer for CVOConfig type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredCVOConfigInformer ¶
func NewFilteredCVOConfigInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredCVOConfigInformer constructs a new informer for CVOConfig type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type CVOConfigInformer ¶
type CVOConfigInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.CVOConfigLister
}
CVOConfigInformer provides access to a shared informer and lister for CVOConfigs.
type Interface ¶
type Interface interface {
// CVOConfigs returns a CVOConfigInformer.
CVOConfigs() CVOConfigInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.